progress_loader_overlay library

Classes

PopScopeLoader
Use this class instead of PopScope to control the ProgressLoader when the user tries to dismiss the enclosing ModalRoute.
ProgressLoader
Can be used to show a widget in an overlay to indicate loading.
ProgressLoaderWidgetController
WillPopScopeLoader
Use this class instead of WillPopScope to control the ProgressLoader when the user tries dismiss the enclosing ModalRoute.

Typedefs

PopScopeLoaderInvokedCallback = void Function(bool didPop, bool wasLoading)
A callback type for informing that a navigation pop has been invoked, whether or not it was handled successfully.
ProgressLoaderWidgetBuilder = Widget Function(BuildContext context, ProgressLoaderWidgetController controller)
Signature for a function that creates a widget, e.g. StatelessWidget.build or State.build.