PopScopeLoader class

Use this class instead of PopScope to control the ProgressLoader when the user tries to dismiss the enclosing ModalRoute.

This can be tuned to prevent the user from popping the route, or to have the ProgressLoader dismiss itself when the user pops the route.

Note that, like Flutter's PopScope, this does not prevent navigation from code using Navigator.pop.

NOTE: PopScope only recognize system back gestures. On iOS there is not consistency for back gestures, and therefore there is no system back gesture. This can lead to issues if you create your own loader widget and your widget is intercepting the swipe gesture. Check _DefaultProgressLoaderWidget in the code to learn more about the issue and see the proposed work-around.

Inheritance

Constructors

PopScopeLoader({Key? key, required Widget child, PopScopeLoaderInvokedCallback? onPopInvoked, bool canPop = true, bool allowPopWhenLoading = false, bool dismissProgressLoaderWhenPopping = false})
const

Properties

allowPopWhenLoading bool
Set this to true to allow the route to be popped even when the ProgressLoader is showing.
final
canPop bool
When false, blocks the current route from being popped.
final
child Widget
The widget below this widget in the tree.
final
dismissProgressLoaderWhenPopping bool
If this and allowPopWhenLoading are true then popping the route will dismiss the ProgressLoader.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPopInvoked PopScopeLoaderInvokedCallback?
Called after a route pop was handled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited