onPopInvoked property

PopScopeLoaderInvokedCallback? onPopInvoked
final

Called after a route pop was handled.

It's not possible to prevent the pop from happening at the time that this method is called; the pop has already happened. Use canPop to disable pops in advance.

This will still be called even when the pop is canceled. A pop is canceled when the relevant Route.popDisposition returns false, such as when canPop is set to false on a PopScope. The didPop parameter indicates whether or not the back navigation actually happened successfully. The wasLoading parameter reports the value ProgressLoader.isLoading had before the back navigation was attempted. If PopScopeLoader.allowPopWhenLoading is set to false this allows you to know whether or not the ProgressLoader was showing before the back navigation was requested.

Implementation

final PopScopeLoaderInvokedCallback? onPopInvoked;