PopScopeLoaderInvokedCallback typedef
A callback type for informing that a navigation pop has been invoked, whether or not it was handled successfully.
Accepts a didPop boolean indicating whether or not back navigation succeeded. Accepts a wasLoading boolean returning the value ProgressLoader.isLoading had before the back navigation was attempted. If PopScopeLoader.allowPopWhenLoading is set to false this allows you to know whether or not the ProgressLoader was showing before the back navigation was requested.
Implementation
typedef PopScopeLoaderInvokedCallback = void Function(
bool didPop,
bool wasLoading,
);