dismissProgressLoaderWhenPopping property
If this and allowPopWhenLoading is true then popping the route will dismiss the ProgressLoader.
It is an error to have this true and allowPopWhenLoading false at the same time, an assert will be thrown.
Implementation
final bool dismissProgressLoaderWhenPopping;